@@ -5,7 +5,7 @@ __all__ = ['__author__', '__author_email__', '__version__', '__logo__', '__docs_
 
 __author__ = "Matthew Wardrop, Dan Frank"
 __author_email__ = "mpwardrop@gmail.com, danfrankj@gmail.com"
-__version__ = "1.1.18"
+__version__ = "1.1.19"
 __logo__ = os.path.join(os.path.dirname(__file__), 'logo.png') if '__file__' in globals() else None
 __docs_url__ = "https://omniduct.readthedocs.io/"
 
@@ -16,7 +16,7 @@ __dependencies__ = [
     "future",  # Python 2/3 support
     "six",  # Python 2/3 support
 
-    "interface_meta>=1.1.0,<1.3",  # Metaclass for creating an extensible well-documented architecture
+    "interface_meta>=1.1.0,<2",  # Metaclass for creating an extensible well-documented architecture
     "pyyaml",  # YAML configuration parsing
     "decorator",  # Decorators used by caching and documentation routines
     "progressbar2>=3.30.0",  # Support for progressbars in logging routines
